#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IDX_LINEAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IDX_LINEAR_HPP_INCLUDED

#include <nt2/interpol/include/functions/scalar/idx_linear.hpp>

#endif
